Documentation
¶
Index ¶
- type MainComponent
- type MainComponent_ChanceChain
- type MainComponent_Chance_Call
- type MainComponent_Expecter
- type MainComponent_ExpecterChain
- type MainComponent_OtherFunctionChain
- func (c MainComponent_OtherFunctionChain[T]) Return(_a0 bytes.Buffer) MainComponent_OtherFunctionChain[T]
- func (c MainComponent_OtherFunctionChain[T]) Run(run func()) MainComponent_OtherFunctionChain[T]
- func (c MainComponent_OtherFunctionChain[T]) RunAndReturn(run func() bytes.Buffer) MainComponent_OtherFunctionChain[T]
- type MainComponent_OtherFunction_Call
- func (_c *MainComponent_OtherFunction_Call) Return(_a0 bytes.Buffer) *MainComponent_OtherFunction_Call
- func (_c *MainComponent_OtherFunction_Call) Run(run func()) *MainComponent_OtherFunction_Call
- func (_c *MainComponent_OtherFunction_Call) RunAndReturn(run func() bytes.Buffer) *MainComponent_OtherFunction_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MainComponent ¶
MainComponent is an autogenerated mock type for the MainComponent type
func NewMainComponent ¶
func NewMainComponent(t interface {
mock.TestingT
Cleanup(func())
}) *MainComponent
NewMainComponent creates a new instance of MainComponent. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MainComponent) Chance ¶
func (_m *MainComponent) Chance(s rand.Source) bool
Chance provides a mock function with given fields: s
func (*MainComponent) EXPECT ¶
func (_m *MainComponent) EXPECT() *MainComponent_Expecter
func (*MainComponent) OtherFunction ¶
func (_m *MainComponent) OtherFunction() bytes.Buffer
OtherFunction provides a mock function with given fields:
type MainComponent_ChanceChain ¶
type MainComponent_ChanceChain[T any] func(*T) *MainComponent_Chance_Call
func (MainComponent_ChanceChain[T]) Return ¶
func (c MainComponent_ChanceChain[T]) Return(_a0 bool) MainComponent_ChanceChain[T]
func (MainComponent_ChanceChain[T]) Run ¶
func (c MainComponent_ChanceChain[T]) Run(run func(s rand.Source)) MainComponent_ChanceChain[T]
func (MainComponent_ChanceChain[T]) RunAndReturn ¶
func (c MainComponent_ChanceChain[T]) RunAndReturn(run func(s rand.Source) bool) MainComponent_ChanceChain[T]
type MainComponent_Chance_Call ¶
MainComponent_Chance_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Chance'
func (*MainComponent_Chance_Call) Return ¶
func (_c *MainComponent_Chance_Call) Return(_a0 bool) *MainComponent_Chance_Call
func (*MainComponent_Chance_Call) Run ¶
func (_c *MainComponent_Chance_Call) Run(run func(s rand.Source)) *MainComponent_Chance_Call
func (*MainComponent_Chance_Call) RunAndReturn ¶
func (_c *MainComponent_Chance_Call) RunAndReturn(run func(rand.Source) bool) *MainComponent_Chance_Call
type MainComponent_Expecter ¶
type MainComponent_Expecter struct {
// contains filtered or unexported fields
}
func (*MainComponent_Expecter) Chance ¶
func (_e *MainComponent_Expecter) Chance(s interface{}) *MainComponent_Chance_Call
Chance is a helper method to define mock.On call
- s rand.Source
func (*MainComponent_Expecter) OtherFunction ¶
func (_e *MainComponent_Expecter) OtherFunction() *MainComponent_OtherFunction_Call
OtherFunction is a helper method to define mock.On call
type MainComponent_ExpecterChain ¶
type MainComponent_ExpecterChain[T any] func(*T) *MainComponent_Expecter
func ExpecterChain ¶
func ExpecterChain[T any](fetch func(*T) *MainComponent) MainComponent_ExpecterChain[T]
func (MainComponent_ExpecterChain[T]) Chance ¶
func (c MainComponent_ExpecterChain[T]) Chance(s interface{}) MainComponent_ChanceChain[T]
func (MainComponent_ExpecterChain[T]) OtherFunction ¶
func (c MainComponent_ExpecterChain[T]) OtherFunction() MainComponent_OtherFunctionChain[T]
type MainComponent_OtherFunctionChain ¶
type MainComponent_OtherFunctionChain[T any] func(*T) *MainComponent_OtherFunction_Call
func (MainComponent_OtherFunctionChain[T]) Return ¶
func (c MainComponent_OtherFunctionChain[T]) Return(_a0 bytes.Buffer) MainComponent_OtherFunctionChain[T]
func (MainComponent_OtherFunctionChain[T]) Run ¶
func (c MainComponent_OtherFunctionChain[T]) Run(run func()) MainComponent_OtherFunctionChain[T]
func (MainComponent_OtherFunctionChain[T]) RunAndReturn ¶
func (c MainComponent_OtherFunctionChain[T]) RunAndReturn(run func() bytes.Buffer) MainComponent_OtherFunctionChain[T]
type MainComponent_OtherFunction_Call ¶
MainComponent_OtherFunction_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OtherFunction'
func (*MainComponent_OtherFunction_Call) Return ¶
func (_c *MainComponent_OtherFunction_Call) Return(_a0 bytes.Buffer) *MainComponent_OtherFunction_Call
func (*MainComponent_OtherFunction_Call) Run ¶
func (_c *MainComponent_OtherFunction_Call) Run(run func()) *MainComponent_OtherFunction_Call
func (*MainComponent_OtherFunction_Call) RunAndReturn ¶
func (_c *MainComponent_OtherFunction_Call) RunAndReturn(run func() bytes.Buffer) *MainComponent_OtherFunction_Call